@@ -27,6 +27,7 @@ __all__ = [
     'uid_of_user',
     'updatefile',
     'get_password',
+    'run_command',
 ]
 
 
@@ -44,6 +45,12 @@ import grp
 import getpass
 import commands
 import sys
+import tempfile
+import errno
+try:
+    import subprocess
+except ImportError, o:
+    subprocess = None
 
 # hashlib only present in python2.5, ssl in python2.6; used together
 # in SSL functionality below
@@ -696,3 +703,42 @@ def get_password(label, user, server, protocol, logger):
         # no password found (or not on OSX), prompt in the usual way
         password = getpass.getpass('Enter password for %s:  ' % label)
     return password
+
+
+#######################################
+def run_command(command, args):
+    # Simple subprocess wrapper for running a command and fetching its exit 
+    # status and output/stderr.
+    if args is None:
+        args = []
+    if type(args) == tuple:
+        args = list(args)
+
+    # Programmer sanity checks
+    assert type(command) in (str, unicode), (
+        'command is %s (%s)' % (command, type(command))
+    )
+    assert type(args) == list, (
+        'args is %s (%s)' % (args, type(args))
+    )
+    for arg in args:
+        assert type(arg) in (str, unicode), 'arg is %s (%s)' % (arg, type(arg))
+
+    stdout = tempfile.TemporaryFile()
+    stderr = tempfile.TemporaryFile()
+
+    cmd = [command] + args
+
+    try:
+        p = subprocess.Popen(cmd, stdout=stdout, stderr=stderr)
+    except OSError, o:
+        if o.errno == errno.ENOENT:
+            # no such file, command not found
+            raise getmailConfigurationError('Program "%s" not found' % command)
+        #else:
+        raise
+
+    rc = p.wait()
+    stdout.seek(0)
+    stderr.seek(0)
+    return (rc, stdout.read().strip(), stderr.read().strip())
